@@ -273,7 +273,7 @@ integrate with GAP  SL*/
 // Platform-specific functions and macros
 
 
-#define libGAP_FORCE_INLINE inline
+#define libGAP_FORCE_INLINE static inline
 
 static inline uint32_t libGAP_rotl32 ( uint32_t x, int8_t r )
 {
